/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @flow strict
 */

import type { NodePath } from '@babel/traverse';
import * as t from '@babel/types';

export declare function isAnyTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.AnyTypeAnnotation>;
export declare function isArrayExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ArrayExpression>;
export declare function isArrayPattern(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ArrayPattern>;
export declare function isArrayTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ArrayTypeAnnotation>;
export declare function isArrowFunctionExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ArrowFunctionExpression>;
export declare function isAssignmentExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.AssignmentExpression>;
export declare function isAssignmentPattern(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.AssignmentPattern>;
export declare function isAwaitExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.AwaitExpression>;
export declare function isBigIntLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BigIntLiteral>;
export declare function isBinary(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Binary>;
export declare function isBinaryExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BinaryExpression>;
export declare function isBindExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BindExpression>;
export declare function isBlock(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Block>;
export declare function isBlockParent(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BlockParent>;
export declare function isBlockStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BlockStatement>;
export declare function isBooleanLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BooleanLiteral>;
export declare function isBooleanLiteralTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BooleanLiteralTypeAnnotation>;
export declare function isBooleanTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BooleanTypeAnnotation>;
export declare function isBreakStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.BreakStatement>;
export declare function isCallExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.CallExpression>;
export declare function isCatchClause(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.CatchClause>;
export declare function isClass(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Class>;
export declare function isClassBody(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ClassBody>;
export declare function isClassDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ClassDeclaration>;
export declare function isClassExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ClassExpression>;
export declare function isClassImplements(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ClassImplements>;
export declare function isClassMethod(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ClassMethod>;
export declare function isClassPrivateMethod(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ClassPrivateMethod>;
export declare function isClassPrivateProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ClassPrivateProperty>;
export declare function isClassProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ClassProperty>;
export declare function isCompletionStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.CompletionStatement>;
export declare function isConditional(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Conditional>;
export declare function isConditionalExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ConditionalExpression>;
export declare function isContinueStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ContinueStatement>;
export declare function isDebuggerStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DebuggerStatement>;
export declare function isDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Declaration>;
export declare function isDeclareClass(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareClass>;
export declare function isDeclareExportAllDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareExportAllDeclaration>;
export declare function isDeclareExportDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareExportDeclaration>;
export declare function isDeclareFunction(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareFunction>;
export declare function isDeclareInterface(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareInterface>;
export declare function isDeclareModule(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareModule>;
export declare function isDeclareModuleExports(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareModuleExports>;
export declare function isDeclareOpaqueType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareOpaqueType>;
export declare function isDeclareTypeAlias(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareTypeAlias>;
export declare function isDeclareVariable(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclareVariable>;
export declare function isDeclaredPredicate(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DeclaredPredicate>;
export declare function isDecorator(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Decorator>;
export declare function isDirective(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Directive>;
export declare function isDirectiveLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DirectiveLiteral>;
export declare function isDoExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DoExpression>;
export declare function isDoWhileStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.DoWhileStatement>;
export declare function isEmptyStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.EmptyStatement>;
export declare function isEmptyTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.EmptyTypeAnnotation>;
export declare function isExistsTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExistsTypeAnnotation>;
export declare function isExportAllDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExportAllDeclaration>;
export declare function isExportDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExportDeclaration>;
export declare function isExportDefaultDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExportDefaultDeclaration>;
export declare function isExportDefaultSpecifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExportDefaultSpecifier>;
export declare function isExportNamedDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExportNamedDeclaration>;
export declare function isExportNamespaceSpecifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExportNamespaceSpecifier>;
export declare function isExportSpecifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExportSpecifier>;
export declare function isExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Expression>;
export declare function isExpressionStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExpressionStatement>;
export declare function isExpressionWrapper(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ExpressionWrapper>;
export declare function isFile(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.File>;
export declare function isFlow(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Flow>;
export declare function isFlowBaseAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FlowBaseAnnotation>;
export declare function isFlowDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FlowDeclaration>;
export declare function isFlowPredicate(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FlowPredicate>;
export declare function isFlowType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FlowType>;
export declare function isFor(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.For>;
export declare function isForInStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ForInStatement>;
export declare function isForOfStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ForOfStatement>;
export declare function isForStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ForStatement>;
export declare function isForXStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ForXStatement>;
export declare function isFunction(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Function>;
export declare function isFunctionDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FunctionDeclaration>;
export declare function isFunctionExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FunctionExpression>;
export declare function isFunctionParent(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FunctionParent>;
export declare function isFunctionTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FunctionTypeAnnotation>;
export declare function isFunctionTypeParam(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.FunctionTypeParam>;
export declare function isGenericTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.GenericTypeAnnotation>;
export declare function isIdentifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Identifier>;
export declare function isIfStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.IfStatement>;
export declare function isImmutable(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Immutable>;
export declare function isImport(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Import>;
export declare function isImportDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ImportDeclaration>;
export declare function isImportDefaultSpecifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ImportDefaultSpecifier>;
export declare function isImportNamespaceSpecifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ImportNamespaceSpecifier>;
export declare function isImportSpecifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ImportSpecifier>;
export declare function isInferredPredicate(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.InferredPredicate>;
export declare function isInterfaceDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.InterfaceDeclaration>;
export declare function isInterfaceExtends(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.InterfaceExtends>;
export declare function isInterfaceTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.InterfaceTypeAnnotation>;
export declare function isInterpreterDirective(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.InterpreterDirective>;
export declare function isIntersectionTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.IntersectionTypeAnnotation>;
export declare function isJSX(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSX>;
export declare function isJSXAttribute(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXAttribute>;
export declare function isJSXClosingElement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXClosingElement>;
export declare function isJSXClosingFragment(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXClosingFragment>;
export declare function isJSXElement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXElement>;
export declare function isJSXEmptyExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXEmptyExpression>;
export declare function isJSXExpressionContainer(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXExpressionContainer>;
export declare function isJSXFragment(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXFragment>;
export declare function isJSXIdentifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXIdentifier>;
export declare function isJSXMemberExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXMemberExpression>;
export declare function isJSXNamespacedName(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXNamespacedName>;
export declare function isJSXOpeningElement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXOpeningElement>;
export declare function isJSXOpeningFragment(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXOpeningFragment>;
export declare function isJSXSpreadAttribute(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXSpreadAttribute>;
export declare function isJSXSpreadChild(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXSpreadChild>;
export declare function isJSXText(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.JSXText>;
export declare function isLVal(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.LVal>;
export declare function isLabeledStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.LabeledStatement>;
export declare function isLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Literal>;
export declare function isLogicalExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.LogicalExpression>;
export declare function isLoop(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Loop>;
export declare function isMemberExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.MemberExpression>;
export declare function isMetaProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.MetaProperty>;
export declare function isMethod(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Method>;
export declare function isMixedTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.MixedTypeAnnotation>;
export declare function isModuleDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ModuleDeclaration>;
export declare function isModuleSpecifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ModuleSpecifier>;
export declare function isNewExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.NewExpression>;
export declare function isNoop(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Noop>;
export declare function isNullLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.NullLiteral>;
export declare function isNullLiteralTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.NullLiteralTypeAnnotation>;
export declare function isNullableTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.NullableTypeAnnotation>;
export declare function isNumberLiteralTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.NumberLiteralTypeAnnotation>;
export declare function isNumberTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.NumberTypeAnnotation>;
export declare function isNumericLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.NumericLiteral>;
export declare function isObjectExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectExpression>;
export declare function isObjectMember(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectMember>;
export declare function isObjectMethod(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectMethod>;
export declare function isObjectPattern(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectPattern>;
export declare function isObjectProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectProperty>;
export declare function isObjectTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectTypeAnnotation>;
export declare function isObjectTypeCallProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectTypeCallProperty>;
export declare function isObjectTypeIndexer(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectTypeIndexer>;
export declare function isObjectTypeInternalSlot(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectTypeInternalSlot>;
export declare function isObjectTypeProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectTypeProperty>;
export declare function isObjectTypeSpreadProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ObjectTypeSpreadProperty>;
export declare function isOpaqueType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.OpaqueType>;
export declare function isOptionalCallExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.OptionalCallExpression>;
export declare function isOptionalMemberExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.OptionalMemberExpression>;
export declare function isParenthesizedExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ParenthesizedExpression>;
export declare function isPattern(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Pattern>;
export declare function isPatternLike(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.PatternLike>;
export declare function isPipelineBareFunction(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.PipelineBareFunction>;
export declare function isPipelinePrimaryTopicReference(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.PipelinePrimaryTopicReference>;
export declare function isPipelineTopicExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.PipelineTopicExpression>;
export declare function isPrivate(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Private>;
export declare function isPrivateName(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.PrivateName>;
export declare function isProgram(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Program>;
export declare function isProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Property>;
export declare function isPureish(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Pureish>;
export declare function isQualifiedTypeIdentifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.QualifiedTypeIdentifier>;
export declare function isRegExpLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.RegExpLiteral>;
export declare function isRestElement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.RestElement>;
export declare function isReturnStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ReturnStatement>;
export declare function isScopable(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Scopable>;
export declare function isSequenceExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.SequenceExpression>;
export declare function isSpreadElement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.SpreadElement>;
export declare function isStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Statement>;
export declare function isStringLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.StringLiteral>;
export declare function isStringLiteralTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.StringLiteralTypeAnnotation>;
export declare function isStringTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.StringTypeAnnotation>;
export declare function isSuper(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Super>;
export declare function isSwitchCase(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.SwitchCase>;
export declare function isSwitchStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.SwitchStatement>;
export declare function isTSAnyKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSAnyKeyword>;
export declare function isTSArrayType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSArrayType>;
export declare function isTSAsExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSAsExpression>;
export declare function isTSBooleanKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSBooleanKeyword>;
export declare function isTSCallSignatureDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSCallSignatureDeclaration>;
export declare function isTSConditionalType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSConditionalType>;
export declare function isTSConstructSignatureDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSConstructSignatureDeclaration>;
export declare function isTSConstructorType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSConstructorType>;
export declare function isTSDeclareFunction(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSDeclareFunction>;
export declare function isTSDeclareMethod(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSDeclareMethod>;
export declare function isTSEntityName(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSEntityName>;
export declare function isTSEnumDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSEnumDeclaration>;
export declare function isTSEnumMember(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSEnumMember>;
export declare function isTSExportAssignment(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSExportAssignment>;
export declare function isTSExpressionWithTypeArguments(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSExpressionWithTypeArguments>;
export declare function isTSExternalModuleReference(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSExternalModuleReference>;
export declare function isTSFunctionType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSFunctionType>;
export declare function isTSImportEqualsDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSImportEqualsDeclaration>;
export declare function isTSImportType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSImportType>;
export declare function isTSIndexSignature(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSIndexSignature>;
export declare function isTSIndexedAccessType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSIndexedAccessType>;
export declare function isTSInferType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSInferType>;
export declare function isTSInterfaceBody(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSInterfaceBody>;
export declare function isTSInterfaceDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSInterfaceDeclaration>;
export declare function isTSIntersectionType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSIntersectionType>;
export declare function isTSLiteralType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSLiteralType>;
export declare function isTSMappedType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSMappedType>;
export declare function isTSMethodSignature(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSMethodSignature>;
export declare function isTSModuleBlock(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSModuleBlock>;
export declare function isTSModuleDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSModuleDeclaration>;
export declare function isTSNamespaceExportDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSNamespaceExportDeclaration>;
export declare function isTSNeverKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSNeverKeyword>;
export declare function isTSNonNullExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSNonNullExpression>;
export declare function isTSNullKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSNullKeyword>;
export declare function isTSNumberKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSNumberKeyword>;
export declare function isTSObjectKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSObjectKeyword>;
export declare function isTSOptionalType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSOptionalType>;
export declare function isTSParameterProperty(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSParameterProperty>;
export declare function isTSParenthesizedType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSParenthesizedType>;
export declare function isTSPropertySignature(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSPropertySignature>;
export declare function isTSQualifiedName(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSQualifiedName>;
export declare function isTSRestType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSRestType>;
export declare function isTSStringKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSStringKeyword>;
export declare function isTSSymbolKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSSymbolKeyword>;
export declare function isTSThisType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSThisType>;
export declare function isTSTupleType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTupleType>;
export declare function isTSType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSType>;
export declare function isTSTypeAliasDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeAliasDeclaration>;
export declare function isTSTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeAnnotation>;
export declare function isTSTypeAssertion(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeAssertion>;
export declare function isTSTypeElement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeElement>;
export declare function isTSTypeLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeLiteral>;
export declare function isTSTypeOperator(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeOperator>;
export declare function isTSTypeParameter(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeParameter>;
export declare function isTSTypeParameterDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeParameterDeclaration>;
export declare function isTSTypeParameterInstantiation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeParameterInstantiation>;
export declare function isTSTypePredicate(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypePredicate>;
export declare function isTSTypeQuery(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeQuery>;
export declare function isTSTypeReference(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSTypeReference>;
export declare function isTSUndefinedKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSUndefinedKeyword>;
export declare function isTSUnionType(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSUnionType>;
export declare function isTSUnknownKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSUnknownKeyword>;
export declare function isTSVoidKeyword(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TSVoidKeyword>;
export declare function isTaggedTemplateExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TaggedTemplateExpression>;
export declare function isTemplateElement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TemplateElement>;
export declare function isTemplateLiteral(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TemplateLiteral>;
export declare function isTerminatorless(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Terminatorless>;
export declare function isThisExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ThisExpression>;
export declare function isThisTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ThisTypeAnnotation>;
export declare function isThrowStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.ThrowStatement>;
export declare function isTryStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TryStatement>;
export declare function isTupleTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TupleTypeAnnotation>;
export declare function isTypeAlias(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TypeAlias>;
export declare function isTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TypeAnnotation>;
export declare function isTypeCastExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TypeCastExpression>;
export declare function isTypeParameter(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TypeParameter>;
export declare function isTypeParameterDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TypeParameterDeclaration>;
export declare function isTypeParameterInstantiation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TypeParameterInstantiation>;
export declare function isTypeofTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.TypeofTypeAnnotation>;
export declare function isUnaryExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.UnaryExpression>;
export declare function isUnaryLike(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.UnaryLike>;
export declare function isUnionTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.UnionTypeAnnotation>;
export declare function isUpdateExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.UpdateExpression>;
export declare function isUserWhitespacable(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.UserWhitespacable>;
export declare function isVariableDeclaration(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.VariableDeclaration>;
export declare function isVariableDeclarator(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.VariableDeclarator>;
export declare function isVariance(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Variance>;
export declare function isVoidTypeAnnotation(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.VoidTypeAnnotation>;
export declare function isWhile(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.While>;
export declare function isWhileStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.WhileStatement>;
export declare function isWithStatement(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.WithStatement>;
export declare function isYieldExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.YieldExpression>;
export declare function isBindingIdentifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Identifier>;
export declare function isBlockScoped(
  path: NodePath,
  props?: object | null,
): path is NodePath<
  t.FunctionDeclaration | t.ClassDeclaration | t.VariableDeclaration
>;
export declare function isGenerated(
  path: NodePath,
  props?: object | null,
): boolean;
export declare function isPure(path: NodePath, props?: object | null): boolean;
export declare function isReferenced(
  path: NodePath,
  props?: object | null,
): boolean;
export declare function isReferencedIdentifier(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Identifier | t.JSXIdentifier>;
export declare function isReferencedMemberExpression(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.MemberExpression>;
export declare function isScope(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.Scopable>;
export declare function isUser(path: NodePath, props?: object | null): boolean;
export declare function isVar(
  path: NodePath,
  props?: object | null,
): path is NodePath<t.VariableDeclaration>;
